@@ -1,4 +1,7 @@
-__all__ = ['Colors']
+__all__ = ['Colors', 'bool2symbol']
+
+# True => Green checkmark, False => Big red X
+bool2symbol = {True: u'\u2705', False: u'\N{CROSS MARK}'}
 
 
 class Colors:
