@@ -1,10 +1,12 @@
 # pylint: disable=invalid-name
 from typing import NamedTuple
 import re
+from pathlib import Path
 
 __all__ = ('__version__', 'version_info')
 
-__version__ = '0.0.3'
+with Path(__file__).with_name('_version.txt').open('r') as f:
+    __version__ = f.readline().strip()
 
 
 class Version(NamedTuple):
